==> dimtim-utils-0.0.16.tar.gz: dimtim-utils-0.0.16/README.md <==
# dimtim-utils

Python utils for Dim-Tim projects

### Changelog

__v0.0.7__ _\[10.12.2021\]_

* Added _utils.text.inline(str)_ function

-------------------------------------------------------------------------------

__v0.0.8__ _\[10.12.2021\]_

* Updated _utils.debug.timeit(str?)_ function

-------------------------------------------------------------------------------

__v0.0.9__ _\[17.01.2022\]_

* Added _utils.decorators.freezeargs()_ decorator

-------------------------------------------------------------------------------

__v0.0.10__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.11__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.12__ _\[17.01.2022\]_

* Small json serializer fixes

-------------------------------------------------------------------------------

__v0.0.13__ _\[22.01.2022\]_

* Added _out_ argument to _utils.debug.timeit(str?, Logger?)_ to specify logger output
* Small fix in importing module
* Added _utils.text.to_kebab_case(str)_ function
* Added some tests

-------------------------------------------------------------------------------

__v0.0.14__ _\[23.01.2022\]_

* Fix _helpers.management_ import without installed __python-crontab__ library

-------------------------------------------------------------------------------

__v0.0.15__ _\[31.01.2022\]_

* Added _utils.terminal.show_progress(int, int, str?, IOBase?)_ function

-------------------------------------------------------------------------------

__v0.0.16__ _\[31.01.2022\]_

* Fix _utils.terminal.show_progress(int, int, str?, IOBase?)_ function

==> dimtim-utils-0.0.17.tar.gz: dimtim-utils-0.0.17/README.md <==
# dimtim-utils

Python utils for Dim-Tim projects

### Changelog

__v0.0.7__ _\[10.12.2021\]_

* Added `utils.text.inline(str)` function

-------------------------------------------------------------------------------

__v0.0.8__ _\[10.12.2021\]_

* Update `utils.debug.timeit(str?)` function

-------------------------------------------------------------------------------

__v0.0.9__ _\[17.01.2022\]_

* Added `utils.decorators.freezeargs()` decorator

-------------------------------------------------------------------------------

__v0.0.10__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.11__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.12__ _\[17.01.2022\]_

* Small json serializer fixes

-------------------------------------------------------------------------------

__v0.0.13__ _\[22.01.2022\]_

* Added `out` argument to `utils.debug.timeit(str?, Logger?)` to specify logger output
* Small fix in importing module
* Added `utils.text.to_kebab_case(str)` function
* Added some tests

-------------------------------------------------------------------------------

__v0.0.14__ _\[23.01.2022\]_

* Fix `helpers.management` import without installed __python-crontab__ library

-------------------------------------------------------------------------------

__v0.0.15__ _\[31.01.2022\]_

* Added `utils.terminal.show_progress(int, int, str?, IOBase?)` function

-------------------------------------------------------------------------------

__v0.0.16__ _\[31.01.2022\]_

* Fix `utils.terminal.show_progress(int, int, str?, IOBase?)` function

-------------------------------------------------------------------------------

__v0.0.17__ _\[26.05.2022\]_

* Fix `utils.json.JsonEncoder` datetime serialization
* Update requirements
